@@ -31,7 +31,6 @@ sub setup_once ($self, $add_global_event_processor, $get_current_hub) {
           data        => {
             url         => $tx->req->url->to_string,
             method      => $tx->req->method,
-            status_code => $tx->res->code,
           },
         });
 
@@ -50,8 +49,10 @@ sub setup_once ($self, $add_global_event_processor, $get_current_hub) {
       })
         if $self->breadcrumbs;
 
-      if ($self->tracing) {
-        $span->set_http_status($tx->res->code);
+      if ($span) {
+        if (my $http_status = $tx->res->code) {
+          $span->set_http_status($http_status);
+        }
         $span->finish();
       }
 
